package com.ruoyi.frequency.browserecord.service;

import java.util.List;

import com.ruoyi.controller.req.CollectPageReq;
import com.ruoyi.frequency.browserecord.entity.BrowseRecord;
import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.response.ResponseData;
import com.ruoyi.vo.UserVo;

/**
 * 浏览记录Service接口
 * 
 * @author liwenlong
 * @date 2023-11-25
 */
public interface BrowseRecordService extends IService<BrowseRecord>
{
    /**
     * 查询浏览记录
     * 
     * @param id 浏览记录主键
     * @return 浏览记录
     */
    public BrowseRecord selectBrowseRecordById(Long id);

    /**
     * 查询浏览记录列表
     * 
     * @param browseRecord 浏览记录
     * @return 浏览记录集合
     */
    public List<BrowseRecord> selectBrowseRecordList(BrowseRecord browseRecord);

    /**
     * 新增浏览记录
     * 
     * @param browseRecord 浏览记录
     * @return 结果
     */
    public int insertBrowseRecord(BrowseRecord browseRecord);

    /**
     * 修改浏览记录
     * 
     * @param browseRecord 浏览记录
     * @return 结果
     */
    public int updateBrowseRecord(BrowseRecord browseRecord);

    /**
     * 批量删除浏览记录
     * 
     * @param ids 需要删除的浏览记录主键集合
     * @return 结果
     */
    public int deleteBrowseRecordByIds(Long[] ids,Integer delFlag);

    ResponseData browsePage(CollectPageReq req, UserVo userVo);

    ResponseData otherBrowsePage(CollectPageReq req, UserVo userVo);
}
